@@ -17,6 +17,7 @@ from txzmq import ZmqFactory, ZmqEndpoint, ZmqSubConnection
 
 logger = logging.getLogger('mfcloud.client')
 
+
 class ApiRpcClient(object):
 
     def __init__(self, host='0.0.0.0'):
@@ -56,7 +57,8 @@ class ApiRpcClient(object):
         def failed(failure):
 
             if failure.type == ConnectionRefusedError:
-                print('\nConnection failure. Server is not started? \n\nRun "mfcloud service start"\n')
+                print('\nConnection failure. Server is not started? \n\nRefer to documentation at '
+                      'http://mfcloud.readthedocs.org/ for instructions how to start the server.\n')
             else:
                 print('Failed to execute the task: %s' % failure.getErrorMessage())
             self.reactor.stop()
@@ -132,6 +134,7 @@ class ApiRpcClient(object):
                 'path': remote_path,
                 'remote': self.host,
             }
+            print command
             os.system(command)
 
             path = remote_path
@@ -155,7 +158,6 @@ class ApiRpcClient(object):
                     #if name.endswith(app['name']):
                     #    name = name[0:-len(app['name']) - 1]
                     name = name[9:]
-                    print service
                     volume_services[name] = '%s' % (
                         #service['ports']['22/tcp'][0]['HostIp'],
                         service['ports']['22/tcp'][0]['HostPort'],
@@ -187,7 +189,8 @@ class ApiRpcClient(object):
 
                 if name in volume_services:
                     data += ' vol: %s' % volume_services[name]
-                    data += ' (%s)' % ', '.join(service['volumes'])
+                    if service['volumes']:
+                        data += ' (%s)' % ', '.join(service['volumes'])
 
                 services.append(data)
 
@@ -242,6 +245,24 @@ class ApiRpcClient(object):
 
         self._remote_exec('inspect', on_result, name, service)
 
+
+    def dns(self, **kwargs):
+
+        def on_result(data):
+
+            table = Texttable(max_width=120)
+            table.set_cols_dtype(['t',  'a'])
+            #table.set_cols_width([20,  100])
+
+            rows = [["Name", "Value"]]
+            for name, val in data.items():
+                rows.append([name, val])
+
+            table.add_rows(rows)
+            print table.draw() + "\\n"
+
+        self._remote_exec('dns', on_result)
+
     def remove(self, name, **kwargs):
 
         def on_result(data):
@@ -304,6 +325,8 @@ class ApiRpcClient(object):
             'remote_path': destination,
         }
 
+        print command
+
         os.system(command)
 
     def stop(self, name, **kwargs):
@@ -352,6 +375,9 @@ def populate_client_parser(subparsers):
     cmd.add_argument('service', help='Service name')
     cmd.set_defaults(func='inspect')
 
+    cmd = subparsers.add_parser('dns', help='List dns records')
+    cmd.set_defaults(func='dns')
+
 
     # # # mfcloud use ubuntu@myserver.com
     # fig_cmd = subparsers.add_parser('fig', help='Executes fig commands')
